;;; SKK

;;; Copyright (C) 2005 The Meadow Team

;; Author: KOSEKI Yoshinori <kose@meadowy.org>

(cond
 ((null skk-large-jisyo)
  (setq skk-large-jisyo (expand-file-name "etc/skk/SKK-JISYO.L" 
					  netinstall-pkg-dir)))
 ((listp skk-large-jisyo)
  )
 ((not (file-exists-p skk-large-jisyo))
  (setq skk-large-jisyo (expand-file-name "etc/skk/SKK-JISYO.L" 
					  netinstall-pkg-dir))))

(unless (file-exists-p skk-tut-file)
  (setq skk-tut-file (expand-file-name "etc/skk/SKK.tut" 
				       netinstall-pkg-dir)))

;;; auto-autoloads.el ends here
